#include "MessengerC.h"
#include <ace/streams.h>

int main(int argc, char* argv[])
{
	try {
		// Initialize the ORB.
		CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);

		// Read and destringify the Messenger object's IOR.
		CORBA::Object_var obj = orb->string_to_object("file://Messenger.ior");
		if( CORBA::is_nil(obj.in())) {
			cerr << "Could not get Messenger IOR." << endl;
			return 1;
		}

		// Narrow the IOR to a Messenger object reference.
		Messenger_var messenger = Messenger::_narrow(obj.in());
		if( CORBA::is_nil(messenger.in())) {
			cerr << "IOR was not a Messenger object reference." << endl;
			return 1;
		}

		// Send a message the Messenger object.
		CORBA::String_var msg = CORBA::string_dup("Hello!");
		messenger->send_message("TAO User", "Test", msg.inout());

		// Print the Messenger's reply.
		cout << "Reply: " << msg.in() << endl;
		return 0;
	}
	catch (CORBA::Exception& ex) {
		cerr << "CORBA exception: " << ex << endl;
	}
	return 1;
}
